Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(767)

Unified Diff: pkg/polymer/lib/src/transform/polyfill_injector.dart

Issue 23478015: Apply several phases only to entrypoint files (which currently are identified as (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 7 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: pkg/polymer/lib/src/transform/polyfill_injector.dart
diff --git a/pkg/polymer/lib/src/transform/polyfill_injector.dart b/pkg/polymer/lib/src/transform/polyfill_injector.dart
index 899fdd81d72c725b6666e918f04a7240a40e182a..6e13b9007725e7c8529600f18f5fc8c009ae8b33 100644
--- a/pkg/polymer/lib/src/transform/polyfill_injector.dart
+++ b/pkg/polymer/lib/src/transform/polyfill_injector.dart
@@ -22,8 +22,8 @@ import 'common.dart';
* css shimming).
*/
class PolyfillInjector extends Transformer {
- /** Only run this transformer on .html files. */
- final String allowedExtensions = ".html";
+ /** Only run on entrypoint .html files under web or test. */
+ Future<bool> isPrimary(Asset input) => isHtmlInWebOrTest(input.id);
Future apply(Transform transform) {
var id = transform.primaryInput.id;

Powered by Google App Engine
This is Rietveld 408576698